@@ -21,10 +21,6 @@ class RasaCoreException(RasaException):
     """Basic exception for errors raised by Rasa Core."""
 
 
-class RasaXTermsError(RasaException):
-    """Error in case the user didn't accept the Rasa X terms."""
-
-
 class InvalidParameterException(RasaException, ValueError):
     """Raised when an invalid parameter is used."""
 
